You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@dolphinscheduler.apache.org by "XIJIU123 (via GitHub)" <gi...@apache.org> on 2024/05/31 01:35:17 UTC
Re: [I] [DSIP-35][Cluster Task Insights]:Add a series of monitoring indicators to reflect the running status of tasks [dolphinscheduler]
XIJIU123 commented on issue #15921:
URL: https://github.com/apache/dolphinscheduler/issues/15921#issuecomment-2141088548
`numeric value
Number of projects
GET /firstPage/query-project-num
parameter:empty
Return value case:
{
"code": 0,
"msg": "成功",
"data": 25,
"failed": false,
"success": true
}
Total workflows, number of online workflows, number of lost workflows
GET /firstPage/query-process-num
parameter:empty
Return value case:
{
"code": 0,
"msg": "成功",
"data": {
"result": [
{
"proc_status": 0,
"proc_count": 475
},
{
"proc_status": 1,
"proc_count": 599
}
]
},
"failed": false,
"success": true
}
Parameter description:
proc_status:0 indicates the online workflow, 1 indicates the total workflow, and 2 indicates the lost workflow
proc_count:the number of workflows
The number of online tasks
GET /firstPage/query-task-num
Parameter:empty
Return value case:
{
"code": 0,
"msg": "成功",
"data": 5756,
"failed": false,
"success": true
}
The number of scheduled tasks, the number of successfully scheduled tasks, and the number of tasks that were successfully scheduled yesterday
GET /firstPage/query-scheduler-num
Parameter:empty
Return value case:
{
"code": 0,
"msg": "成功",
"data": {
"finishSchedulerNum": 8749,
"yesterdaySchedulerNum": 8723,
"totalSchedulerNum":13638,
},
"failed": false,
"success": true
}
Parameter description:
finishSchedulerNum:Today's successful dispatch counts
totalSchedulerNum:The number of tasks that should be scheduled
yesterdaySchedulerNum:The number of successfully scheduled tasks yesterday
manifest
Top 5 Tasks in Running Duration
GET /firstPage/query-timeouttask-top
Parameter:
startDate:(must,type:string,Non-null),start time.
endDate:(must,type:string,Non-null),End time.
Return value case:
{
"code": 0,
"msg": "成功",
"data": [
{
"name": "dwi_breed_estrus_qs",
"count": 0,
"duration": 468
}
],
"failed": false,
"success": true
}
Parameter description:
name:the name of the task
count:the number of executions
duration:time spent (minutes)
Top 5 Failed Tasks
GET /firstPage/query-failtask-top
Parameter:
startDate:(must,type:string,Non-null),start time.
endDate:(must,type:string,Non-null),End time.
Return value case:
{
"code": 0,
"msg": "成功",
"data": [
{
"name": "dwi_breed_estrus_qs",
"count": 0,
"duration": 468
}
],
"failed": false,
"success": true
}
Parameter description:
name: the name of the task
count: the number of executions
duration: time spent (minutes))
Trends (to be determined)
任务状态指标
GET /firstPage/query-task-status-num
Parameter:
startDate:(must,type:string,Non-null),start time.
endDate:(must,type:string,Non-null),End time.
projectCode: (must, string, can be empty), end time.
Return value case:
{
"code": 0,
"msg": "成功",
"data": {
"x": [
0,
...,
23
],
"y": [
{
"data": [
0,
...,
0
],
"name": "成功"
},
{
"data": [
0,
...,
0
],
"name": "失败"
},
{
"data": [
0,
...,
0
],
"name": "停止"
},
{
"data": [
0,
...,
0
],
"name": "其他"
},
{
"data": [
0,
....,
0
],
"name": "全部"
}
]
},
"failed": false,
"success": true
}
Parameter description:
x: x-axis coordinates
y: y-axis coordinate
data: data content
name: task state type
`
--
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.
To unsubscribe, e-mail: commits-unsubscribe@dolphinscheduler.apache.org
For queries about this service, please contact Infrastructure at:
users@infra.apache.org